<?php
if ( !defined( 'ABSPATH' ) ) {
	return;
}

class Theme_Options_for_Flexible_learning_Website {

	/**
	 * Set up actions and filters for this class which adds settings fields, options and validation
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param null
	 * @return null
	 */
	
	public function setupActionsAndFilters() {

		add_action( 'admin_init', array( $this, 'admin_init__addSettingsSectionAndFields' ), 1 );
		add_filter( 'ubc_collab_default_theme_options', array( $this, 'ubc_collab_default_theme_options__addDefaultValues' ), 10, 1 );
		add_filter( 'ubc_collab_theme_options_validate', array( $this, 'ubc_collab_theme_options_validate__validateOptions' ), 10, 2 );

	}/* setupActionsAndFilters() */


	/**
	 * Register the settings section and the fields we need
	 *
	 * @access public
	 * @return void
	 */
	
	public function admin_init__addSettingsSectionAndFields() {

		add_settings_section(
			'flexible-learning-options', // Unique identifier for the settings section
			'FLexible Learning Options', // Section title
			'__return_false', // Section callback (we don't want anything)
			'theme_options' // Menu slug, used to uniquely identify the page; see ubc_collab_theme_options_add_page()
		);

		add_settings_field(
			'news-events-sections', // Unique identifier for the field for this section
			'News and Events Options', // Setting field label
			array( $this, 'news_events_options' ), // Function that renders the settings field
			'theme_options', // Menu slug, used to uniquely identify the page; see ubc_collab_theme_options_add_page()
			'flexible-learning-options' // Settings section. Same as the first argument in the add_settings_section() above
		);

		add_settings_field(
			'case-studies-sections', // Unique identifier for the field for this section
			'Case Studies Options', // Setting field label
			array( $this, 'case_studies_options' ), // Function that renders the settings field
			'theme_options', // Menu slug, used to uniquely identify the page; see ubc_collab_theme_options_add_page()
			'flexible-learning-options' // Settings section. Same as the first argument in the add_settings_section() above
		);

	}/* admin_init__addSettingsSectionAndFields() */


	/**
	 * Markup for the News and events intro text option
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param null
	 * @return null
	 */
	
	public function news_events_options() {

		// Add the Intro text textarea
		echo "<h3>News and Events landing page introduction text.</h3>";
		echo "<p>";
			UBC_Collab_Theme_Options::textarea( 'news-events-default-message' );
		echo "</p>";
		
		// Add a checkbox for each News + Events Category (not our custom tax. is called 'Categories' not to be confused with the default post 'category')
		echo "<h3>Select which categories you would like to use on the News and Events Landing Page</h3>";
		
		// Fetch all of our custom tax
		$terms = get_terms( 'categories' );

		if( empty( $terms ) || is_wp_error( $terms ) ) {
			return;
		}

		// Loop over each and output a checkbox for each
		echo '<ul>';

		foreach ( $terms as $term ) {
			echo '<li>';
				UBC_Collab_Theme_Options::checkbox( 'news-event-terms-' . $term->slug, 1, $term->name );
			echo '</li>';
		}

		echo '</ul>';

	}/* news_events_options() */


	/**
	 * Markup for the case studies landing page intro text option
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param null
	 * @return null
	 */
	
	public function case_studies_options() {

		// Message shown on the case studies landing page
		echo "<h3>Case Studies landing page introduction text.</h3>";
		echo "<p>";
			UBC_Collab_Theme_Options::textarea( 'case-studies-default-message' );
		echo "</p>";

	}/* case_studies_options() */


	/**
	 * Add default options so that if nothing is saved, we have something to go by
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param (array) $options - Already set options
	 * @return (array) - Modified options with our defauls added 
	 */
	
	public static function ubc_collab_default_theme_options__addDefaultValues( $options ) {

		if ( !is_array( $options ) ) {
			$options = array();
		}

		$defaults = array(
			'news-events-default-message'	=>  "",
			'case-studies-default-message'	=>  "",
		);

		$terms = get_terms( 'categories' );

		foreach ( $terms as $term ) {

			if ( is_wp_error( $terms ) ||  ! $term ) {

				continue;
			}

			$termSlug = $term->slug;

			$addToDefaults = 'news-event-terms-' . $termSlug;

			$defaults[ $addToDefaults ] = 0;

		}

		$options = array_merge( $options, $defaults );

		return $options;

	}/* ubc_collab_default_theme_options__addDefaultValues() */


	/**
	 * Validate theme options on save
	 *
	 * @author Richard Tape <@richardtape>
	 * @since 1.0
	 * @param (array) $input Unknown values.
	 * @return (array) Sanitized theme options ready to be stored in the database.
	 */
	
	public function ubc_collab_theme_options_validate__validateOptions( $output, $input ) {

		// USe our default values as the base
		$starter = static::ubc_collab_default_theme_options__addDefaultValues( array() );

		// At the moment, our theme options onlt seem to have a validate_text method. @todo add more validation to CLF theme options
		$starter['news-events-default-message'] = UBC_Collab_Theme_Options::validate_text( $input['news-events-default-message'], $starter['news-events-default-message'] );
		$starter['case-studies-default-message'] = UBC_Collab_Theme_Options::validate_text( $input['case-studies-default-message'], $starter['case-studies-default-message'] );

		$terms = get_terms( 'categories' );
		foreach ( $terms as $term ) {
			$starter['news-event-terms-' . $term->slug] = (bool) $input['news-event-terms-' . $term->slug];
		}

		// Merge our defaults with the inputs
		$output = array_merge( $output, $starter );

		return $output;

	}/* ubc_collab_theme_options_validate__validateOptions() */
	

}// Class::Theme_Options_for_Flexible_learning_Website


add_action( 'plugins_loaded', 'plugins_loaded__instantiateCTLT_Theme_Options', 10 );

function plugins_loaded__instantiateCTLT_Theme_Options() {

	$Theme_Options_for_Flexible_learning_Website = new Theme_Options_for_Flexible_learning_Website();
	$Theme_Options_for_Flexible_learning_Website->setupActionsAndFilters();

}/* plugins_loaded__instantiateCTLT_Theme_Options() */

